@@ -37,7 +37,7 @@ class RoboState(object):
         """
         return BeautifulSoup(
             self.response.content,
-            features=self.browser.parser, 'html.parser'
+            'html.parser'
         )
 
 
